@@ -1,9 +1,9 @@
-import imp
 import logging
 import logging.config
 import optparse
 
 from kuyruk import Kuyruk
+from config import Config
 
 logger = logging.getLogger(__name__)
 
@@ -20,11 +20,6 @@ def main():
     parser.add_option('--save-failed-tasks', action='store_true')
     options, args = parser.parse_args()
 
-    if options.config:
-        config = imp.load_source('config', options.config)
-    else:
-        config = imp.new_module('config')
-
     if options.logging_config:
         logging.config.fileConfig(options.logging_config)
     else:
@@ -32,16 +27,20 @@ def main():
         level = getattr(logging, options.logging_level)
         logging.basicConfig(level=level)
 
+    config = Config(options.config)
+
     if options.max_load is not None:
-        config.KUYRUK_MAX_LOAD = options.max_load
+        config.MAX_LOAD = options.max_load
 
     if options.max_run_time is not None:
-        config.KUYRUK_MAX_RUN_TIME = options.max_run_time
+        config.MAX_RUN_TIME = options.max_run_time
 
     if options.save_failed_tasks:
-        config.KUYRUK_SAVE_FAILED_TASKS = options.save_failed_tasks
+        config.SAVE_FAILED_TASKS = options.save_failed_tasks
 
-    Kuyruk(config).run(options.queues)
+    kuyruk = Kuyruk()
+    kuyruk.config = config
+    kuyruk.run(options.queues)
 
 if __name__ == '__main__':
     main()
